@@ -58,6 +58,13 @@ Q_LOGGING_CATEGORY(KAMERA_KIOSLAVE, "kamera.kio")
 
 using namespace KIO;
 
+// Pseudo plugin class to embed meta data
+class KIOPluginForMetaData : public QObject
+{
+    Q_OBJECT
+    Q_PLUGIN_METADATA(IID "org.kde.kio.slave.camera" FILE "camera.json")
+};
+
 extern "C"
 {
     Q_DECL_EXPORT int kdemain(int argc, char **argv);
@@ -1199,3 +1206,5 @@ static void frontendCameraStatus(
     object->infoMessage(QString::fromLocal8Bit(status));
 #endif
 }
+
+#include "kamera.moc"
